# -----------------------------------------------------------------
# 
#   MELODY HARMONIZATION WITH INTERPOLATED PROBABILISTIC MODELS
# 
# This package contains the code for automatic melody harmonization
# described in the paper:
# 
# S.A. Raczyński, S. Fukayama, E. Vincent, “Melody harmonisation
# with interpolated probabilistic models,” INRIA Technical
# Report RR-8110, 2012,
# URL: http://hal.inria.fr/hal-00742957/PDF/RR-8110.pdf
# 
# This code has been written by:
#  - Stanisław Raczyński, INRIA
#  - Satoru Fukayama, The University of Tokyo
# 
# The code is licensed under the GNU GENERAL PUBLIC LICENSE
# Version 3, which can be found at:
#   http://www.gnu.org/licenses/gpl-3.0.txt
# 
# Contact information: stanislaw.raczynski@inria.fr
# 
# -----------------------------------------------------------------

library("multicore")

source("settings.R")

runSingleExperiment = function(unitType,       # 0 or 1
                               unitDivision)   # 1, 2, 4, 6, etc.
{
  cat("Running experiments for", unitType, unitDivision, "\n")

  # Loading datastreams to R
  source("preloadDatasets.R", local=TRUE)

  # Training the models
  makePlots = FALSE
  source("trainDistributions.R", local=TRUE)

  # Training interpolation coefficients
  source("trainInterpolationCoefficients.R", local=TRUE)
}

unitTypes     = rep(c(0,1), times=1)
unitDivisions = rep(c(1/32), each=2)

## Train everything
executionTimes = mclapply(1:2, function(ii) {
  unitType = unitTypes[ii]
  unitDivision = unitDivisions[ii]
  runSingleExperiment(unitType=unitType, unitDivision=unitDivision)
})

