# -----------------------------------------------------------------
# 
#   MELODY HARMONIZATION WITH INTERPOLATED PROBABILISTIC MODELS
# 
# This package contains the code for automatic melody harmonization
# described in the paper:
# 
# S.A. Raczyński, S. Fukayama, E. Vincent, “Melody harmonisation
# with interpolated probabilistic models,” INRIA Technical
# Report RR-8110, 2012,
# URL: http://hal.inria.fr/hal-00742957/PDF/RR-8110.pdf
# 
# This code has been written by:
#  - Stanisław Raczyński, INRIA
#  - Satoru Fukayama, The University of Tokyo
# 
# The code is licensed under the GNU GENERAL PUBLIC LICENSE
# Version 3, which can be found at:
#   http://www.gnu.org/licenses/gpl-3.0.txt
# 
# Contact information: stanislaw.raczynski@inria.fr
# 
# -----------------------------------------------------------------

source("harmonizationEvaluation.R")

allFiles = loadData(leadsheetFilenames)

matches = rep(NA, length(allFiles))
for(ii in 1:length(allFiles))
{
  firstNoNonChord = which(allFiles[[ii]][[4]] != 25)[1]
  if(is.na(firstNoNonChord)) next
  firstChordType = which(c(12,17) == allFiles[[ii]][[4]][firstNoNonChord])[1]  # 1 major 2 minor
  firstKeyMode   = floor((allFiles[[ii]][[2]][1]-1) / 12) + 1   # 1 major 2 minor
  cat("chord ", firstChordType, ", key ", firstKeyMode, "\n")
  matches[ii] = (firstChordType == firstKeyMode)
}
cat("Possible bad key modes:\n ", as.character(leadsheets.testing[which(!matches)]), "\n")

maxLengths = sapply(1:length(allFiles), function(ii) {
  rles = rle(paste(allFiles[[ii]][[3]], allFiles[[ii]][[4]]))
  if(any(rles$values != "13 25"))
    return(max(rles$lengths[rles$values != "13 25"]))
  else
    return(NA)
})

