#!/usr/bin/python
# coding: utf-8

import sys
sys.path.append('..')  # needed to load the fukatools module

from musicxml import musicxml as mxp

def parse_chord_data( blocks ):
    # for this method, we handle chord only.
    chord_list = []
    for block in blocks:
        if block[0]["crootstep"] == None:
            crootstep = "NA" # default
        else:
            crootstep = block[0]["crootstep"]

        if block[0]["crootalter"] == None:
            crootalter = 0
        else:
            crootalter = int(block[0]["crootalter"])

        if block[0]["ckind"] == None:
            ckind = "NA"
        else:
            ckind = block[0]["ckind"]

        chord_list.append( (crootstep + ["bb", "b", "", "#", "##"][crootalter + 2], ckind) )

    return chord_list

def fifths_scale_convert_major(fifths):
    # converts a fifths representation of a key to a pitch/alter pair
    (pitch, alter) = { -7:(0,-1), -6:(4,-1), -5:(1,-1), -4:(5,-1), -3:(2,-1),
                       -2:(6,-1), -1:(3,0),   0:(0,0),   1:(4,0),   2:(1,0),
                       3:(5,0),    4:(2,0),   5:(6,0),   6:(3,1),   7:(0,1) }[fifths]
    return pitch, alter

def fifths_scale_convert_minor(fifths):
    # converts a fifths representation of a key to a pitch/alter pair
    (pitch, alter) = { -7:(5,-1), -6:(2,-1), -5:(6,-1), -4:(3,0), -3:(0,0),
                       -2:(4,0),  -1:(1,0),   0:(5,0),   1:(2,0),  2:(6,0),
                        3:(3,1),   4:(0,1),   5:(4,1),   6:(1,1),  7:(5,1) }[fifths]
    return pitch, alter

def parse_tonality_data( blocks ):
    tonality_list = []
    for block in blocks:
        kmode   = block[0]["kmode"]
        kfifths = block[0]["kfifths"]
        if kmode == "major":
            kpitch, kalter = fifths_scale_convert_major(int(kfifths))
        elif kmode == "minor":
            kpitch, kalter = fifths_scale_convert_minor(int(kfifths))
        else:
            raise Exception("Unknown key mode: " + str(kmode))
        tonality_list.append((kpitch, kalter, kmode))
    return tonality_list

def parse_melody_data(blocks):
    # here, we handle melody-set sequence
    # ignore octaves
    # ignore same notes
    # ignore order
    melody_list = []
    #scale = ["C","D","E","F","G","A","B"]
    for block in blocks:
        melodylist_in_beat = []
        for i in range(len(block)):
            if not block[i]["pstep"] == None:
                if block[i]["palter"] == None:
                    palter = 0
                else:
                    palter = int(block[i]["palter"])
                #pstep = block[i]["pstep"] + ["bb", "b", "", "#", "##"][palter + 2]
                melodylist_in_beat.append(block[i]["pstep"] + ["bb", "b", "", "#", "##"][palter + 2] + str(block[i]["pduration"]))
        #melodylist_in_beat.sort()
        melody_in_beat = tuple( set(melodylist_in_beat) )
        melody_list.append( melody_in_beat )

    return melody_list

def prepare_sets(fname, timeUnit, timeUnitDivision):
    tonality_list = []
    chord_list = []
    melody_list = []

    # divide into beats
    blocks, tlist = mxp.divideBeats(mxp.parse(fname), timeUnit,
    timeUnitDivision)

    # generate list for each component (excluding beat information for now)
    chord_list     += parse_chord_data(blocks)
    tonality_list  += parse_tonality_data(blocks)
    melody_list    += parse_melody_data(blocks)

    return {"tonality":tonality_list,
            "chord":chord_list,
            "melody":melody_list}

def fileout(dat, fname):
    f = open(fname, "w")
    for i in range(len(dat)):
        f.write("%s\n" % str(dat[i]))
    f.close()

def _main():
    inputFileName = sys.argv[1]
    outputFileName = sys.argv[2]
    timeUnit = int(sys.argv[3])
    timeUnitDivision = float(sys.argv[4]) # float, because it can be 0.5 for frame of 2 beats
    data = prepare_sets(inputFileName, timeUnit, timeUnitDivision)
    for streamType in ["tonality", "chord", "melody"]:
      fileout(data[streamType],
              outputFileName + "." + streamType)
#      fileout([data[streamType][-1]]+data[streamType][:-1],
#              outputFileName + ".prev." + streamType)

if __name__ == '__main__': _main()

