# -----------------------------------------------------------------
# 
#   MELODY HARMONIZATION WITH INTERPOLATED PROBABILISTIC MODELS
# 
# This package contains the code for automatic melody harmonization
# described in the paper:
# 
# S.A. Raczyński, S. Fukayama, E. Vincent, “Melody harmonisation
# with interpolated probabilistic models,” INRIA Technical
# Report RR-8110, 2012,
# URL: http://hal.inria.fr/hal-00742957/PDF/RR-8110.pdf
# 
# This code has been written by:
#  - Stanisław Raczyński, INRIA
#  - Satoru Fukayama, The University of Tokyo
# 
# The code is licensed under the GNU GENERAL PUBLIC LICENSE
# Version 3, which can be found at:
#   http://www.gnu.org/licenses/gpl-3.0.txt
# 
# Contact information: stanislaw.raczynski@inria.fr
# 
# -----------------------------------------------------------------

# Dataset definitions
testingSetSize = 100
validationSetSize = 100

leadsheetFilenames = read.table("leadsheets/filelist.txt")[,1]
datasetSize = length(leadsheetFilenames)

validationFileNumbers = floor(seq(1, datasetSize-2, length.out=testingSetSize))
testingFileNumbers    = floor(seq(2, datasetSize-1, length.out=testingSetSize))
if(any(validationFileNumbers %in% testingFileNumbers))  # sanity check
  stop("Some files are both in the testing and the validation sets! Try changing dataset sizes in settings.R.")

leadsheets.training   = leadsheetFilenames[  !(seq(1, datasetSize) %in% validationFileNumbers)
                                           & !(seq(1, datasetSize) %in% testingFileNumbers)]
leadsheets.testing    = leadsheetFilenames[testingFileNumbers]
leadsheets.validation = leadsheetFilenames[validationFileNumbers]
