#!/bin/bash
# -----------------------------------------------------------------
# 
#   MELODY HARMONIZATION WITH INTERPOLATED PROBABILISTIC MODELS
# 
# This package contains the code for automatic melody harmonization
# described in the paper:
# 
# S.A. Raczyński, S. Fukayama, E. Vincent, “Melody harmonisation
# with interpolated probabilistic models,” INRIA Technical
# Report RR-8110, 2012,
# URL: http://hal.inria.fr/hal-00742957/PDF/RR-8110.pdf
# 
# This code has been written by:
#  - Stanisław Raczyński, INRIA
#  - Satoru Fukayama, The University of Tokyo
# 
# The code is licensed under the GNU GENERAL PUBLIC LICENSE
# Version 3, which can be found at:
#   http://www.gnu.org/licenses/gpl-3.0.txt
# 
# Contact information: stanislaw.raczynski@inria.fr
# 
# -----------------------------------------------------------------

set -e
egrep -i "<step>|<alter>|<octave>|<duration>" $1.xml | sed -e 's/ //g' -e 's/<\/.*>//g' -e 's/<//' -e 's/>/ /' > temp.txt
R --slave << EOF
  musicxml = read.table("temp.txt", stringsAsFactors=FALSE)
  melody = matrix(NA, 0, 2)
  pitch = NA
  for(ii in 1:nrow(musicxml))
  {
    if(musicxml[ii,1] == "step")
      pitch = which(c("C","","D","","E","F","","G","","A","","B") == musicxml[ii,2]) + 59
      # we assume octave = 4 (C4=60); at least until we get the 'octave' field, where we subtract 59
    if(musicxml[ii,1] == "alter")
    {
      if(is.na(pitch))
        stop("'alter' appeared before 'step'")
      pitch = pitch + as.numeric(musicxml[ii,2])
    }
    if(musicxml[ii,1] == "octave")
    {
      if(is.na(pitch))
        stop("'octave' appeared before 'step'")
      pitch = pitch-59 + 12*(as.numeric(musicxml[ii,2])+1)-1  # we should get MIDI pitch number
    }
    if(musicxml[ii,1] == "duration")
    {
      melody = rbind(melody, c(pitch, as.numeric(musicxml[ii,2])))
      pitch = NA
    }
  }
  write.table(melody, "$1.melody", col.names=FALSE, row.names=FALSE)
EOF
# rm -f temp.txt
