#!/bin/bash
# -----------------------------------------------------------------
# 
#   MELODY HARMONIZATION WITH INTERPOLATED PROBABILISTIC MODELS
# 
# This package contains the code for automatic melody harmonization
# described in the paper:
# 
# S.A. Raczyński, S. Fukayama, E. Vincent, “Melody harmonisation
# with interpolated probabilistic models,” INRIA Technical
# Report RR-8110, 2012,
# URL: http://hal.inria.fr/hal-00742957/PDF/RR-8110.pdf
# 
# This code has been written by:
#  - Stanisław Raczyński, INRIA
#  - Satoru Fukayama, The University of Tokyo
# 
# The code is licensed under the GNU GENERAL PUBLIC LICENSE
# Version 3, which can be found at:
#   http://www.gnu.org/licenses/gpl-3.0.txt
# 
# Contact information: stanislaw.raczynski@inria.fr
# 
# -----------------------------------------------------------------

set -e

function grepParameter()
{
#  greppedLines=`grep -m 1 $2 $1.xml | wc -l`
#  [ $greppedLines -ne 1 ] && return 1
  eval $3=`grep -m 1 $2 $1.xml | sed -e "s/$2//g;s/[<>/]//g;s/ //g"`
}

function checkFile()
{
  grepParameter leadsheets/$1 "fifths" FIFTHS || { echo Key is changing throughout the song! Ignoring the song ; continue ; }
  grepParameter leadsheets/$1 "mode" MODE || { echo Key is changing throughout the song! Ignoring the song ; continue ; }
  R --slave << EOF
    if("$MODE" == "major") cat("$1;", c("Fb","Cb","Gb","Db","Ab","Eb","Bb","F", "C", "G","D","A","E","B","F#","C#","G#")[$FIFTHS+9], "-maj\n", sep="") else cat("$1;", c("Db","Ab","Eb","Bb","F","C","G","D", "A", "E","B","F#","C#","G#","D#","A#","E#")[$FIFTHS+9], "-min\n", sep="")
EOF
}

rm -f keys.txt
for filename in `ls leadsheets/*.xml | sed -e 's/\.xml//' -e 's/leadsheets\///'`; do
  checkFile $filename >> keys.txt
  tail -n 1 keys.txt
done
