#!/bin/sh
# -----------------------------------------------------------------
# 
#   MELODY HARMONIZATION WITH INTERPOLATED PROBABILISTIC MODELS
# 
# This package contains the code for automatic melody harmonization
# described in the paper:
# 
# S.A. Raczyński, S. Fukayama, E. Vincent, “Melody harmonisation
# with interpolated probabilistic models,” INRIA Technical
# Report RR-8110, 2012,
# URL: http://hal.inria.fr/hal-00742957/PDF/RR-8110.pdf
# 
# This code has been written by:
#  - Stanisław Raczyński, INRIA
#  - Satoru Fukayama, The University of Tokyo
# 
# The code is licensed under the GNU GENERAL PUBLIC LICENSE
# Version 3, which can be found at:
#   http://www.gnu.org/licenses/gpl-3.0.txt
# 
# Contact information: stanislaw.raczynski@inria.fr
# 
# -----------------------------------------------------------------

if [ $# -ne 3 ]
then
  echo "Error in $0 - Invalid Argument Count"
  echo "Syntax: $0 <unit_division> <interpolation> <filename>"
  echo "  unit_division := [1, 0.5, 0.25, 0.125, 0.0625, 0.03125]"
  echo "  interpolation := [linear, loglinear]"
  exit
fi
R --slave << EOF
  source("settings.R")
  source("datasetDefinitions.R")
  source("prepareDataForTesting.R")
  source("harmonizeMelody.R")

  inputFile = prepareFile("$3", unitType=1, unitDivision=$1)

  load(paste("data/fudgeFactors_1_", $1, "_ignore.Rdata", sep=""))
  if("$2" == "linear") {
    interpolationCoefficients = fudgeFactors[,1]\$par
  } else
    interpolationCoefficients = fudgeFactors[,6]\$par

  harmonizationSequence = harmonizeMelody(inputFile[[1]], inputFile[[2]], interpolation="$2", interpolationCoefficients=interpolationCoefficients, unitDivision=$1)
  cat("Chord roots:\n", harmonizationSequence[1,], "\n")
  cat("Chord types:\n", harmonizationSequence[2,], "\n")
EOF
