#!/bin/bash
# -----------------------------------------------------------------
# 
#   MELODY HARMONIZATION WITH INTERPOLATED PROBABILISTIC MODELS
# 
# This package contains the code for automatic melody harmonization
# described in the paper:
# 
# S.A. Raczyński, S. Fukayama, E. Vincent, “Melody harmonisation
# with interpolated probabilistic models,” INRIA Technical
# Report RR-8110, 2012,
# URL: http://hal.inria.fr/hal-00742957/PDF/RR-8110.pdf
# 
# This code has been written by:
#  - Stanisław Raczyński, INRIA
#  - Satoru Fukayama, The University of Tokyo
# 
# The code is licensed under the GNU GENERAL PUBLIC LICENSE
# Version 3, which can be found at:
#   http://www.gnu.org/licenses/gpl-3.0.txt
# 
# Contact information: stanislaw.raczynski@inria.fr
# 
# -----------------------------------------------------------------

set -e  # stop the script on errors

if [[ -z $2 ]]; then
  echo "You need to specify the time time unit (0=quarter notes, 1=beats) and the time unit division: 1, 2, 3, 6, ..."
  exit 0
fi

exec > >(tee logs/preparation.log) # log the output

dataFolder=data
leadsheetFolder=leadsheets
dataStreamFolder=$dataFolder/datastreams

rm -f $leadsheetFolder/filelist.txt
for filename in `ls -1 $leadsheetFolder/*.xml | sed -e "s/leadsheets\///"`; do
  echo "Converting $filename"
  python convertToDataStreams.py $leadsheetFolder/$filename $dataStreamFolder/$filename $1 $2

  # Remove parenthesis, trailing commas and some quotation marks for easier processing:
  sed -i "s/(//g;s/)//g;s/'//g;s/,$//g" $dataStreamFolder/$filename.melody
  sed -i "s/(//g;s/)//g;s/'//g;s/ //g" $dataStreamFolder/$filename.chord
  sed -i "s/(//g;s/)//g;s/'//g;s/ //g" $dataStreamFolder/$filename.tonality
  echo $filename >> $leadsheetFolder/filelist.txt
done
