# -----------------------------------------------------------------
# 
#   MELODY HARMONIZATION WITH INTERPOLATED PROBABILISTIC MODELS
# 
# This package contains the code for automatic melody harmonization
# described in the paper:
# 
# S.A. Raczyński, S. Fukayama, E. Vincent, “Melody harmonisation
# with interpolated probabilistic models,” INRIA Technical
# Report RR-8110, 2012,
# URL: http://hal.inria.fr/hal-00742957/PDF/RR-8110.pdf
# 
# This code has been written by:
#  - Stanisław Raczyński, INRIA
#  - Satoru Fukayama, The University of Tokyo
# 
# The code is licensed under the GNU GENERAL PUBLIC LICENSE
# Version 3, which can be found at:
#   http://www.gnu.org/licenses/gpl-3.0.txt
# 
# Contact information: stanislaw.raczynski@inria.fr
# 
# -----------------------------------------------------------------

source('settings.R')
source("calculateCrossEntropy.R")

unitTypes = c(0,1)
unitDivisions = c(1/32,1/16,0.125,0.25,0.5,1,2,3)

priorOnlyEntropies = matrix(NA, length(unitTypes), length(unitDivisions))

for(ii in seq_along(unitTypes)) for(jj in seq_along(unitDivisions))
{
  cat("unitType =", unitTypes[ii], "| unitDivision =", unitDivisions[jj], "\n")

  allData = loadData(dataset="validation", datasetSuffix=paste("_", unitTypes[ii], "_", unitDivisions[jj], "_", stateTyingMethod, sep=""))

  fudgeFactors = optim(par=c(1,1), fn=function(x) calculateCrossEntropies(c(0,0,0,x), interpolation="linear", allData=allData, avoidInfinity=TRUE, silent=FALSE), method="L-BFGS-B", lower=c(0,0), control=list(fnscale=1e-6))

  priorOnlyEntropies[ii,jj] = calculateCrossEntropies(c(0,0,0,fudgeFactors$par), interpolation="linear", allData=allData, avoidInfinity=FALSE)
}

save(priorOnlyEntropies, file="data/priorOnlyEntropies.Rdata")
